@@ -3,6 +3,7 @@ from matplotlib.ticker import FuncFormatter
 
 from flask_scenario_testing.analysis.report_sections.ReportSection import ReportSection
 from flask_scenario_testing.analysis.services.ComputeTransactionSignature import ComputeTransactionSignature
+import json
 
 
 class PlotTransactionSignatures(ReportSection):
@@ -14,8 +15,22 @@ class PlotTransactionSignatures(ReportSection):
     def print(self, _) -> None:
         signatures = [(scenario, self.service.compute_signature(scenario)) for scenario in self.service.scenarios()]
 
-        self.plot_absolute_signatures(signatures)
-        self.plot_relative_signatures(signatures, show_percents=False)
+        result = []
+
+        for idx, service_time in enumerate(signatures[0][1]):
+            result.append(dict(
+                name=service_time.endpoint_name,
+                old_service_time=service_time.value,
+                new_service_time=signatures[1][1][idx].value
+            ))
+
+        print(json.dumps(result, indent=2))
+        print(result)
+        exit(-1)
+
+        # self.plot_absolute_signatures(signatures)
+        # self.plot_relative_signatures(signatures, show_percents=False)
+        self.plot_recall_and_precision(signatures)
         # self.plot_relative_signatures(signatures, show_percents=True)
 
     def plot_absolute_signatures(self, signatures):
@@ -41,10 +56,6 @@ class PlotTransactionSignatures(ReportSection):
 
         base_scenario, base_signature = signatures[0]
 
-        print(signatures)
-        exit(-1)
-
-
         for scenario, signature in signatures[1:-1]:
             plt.gcf().subplots_adjust(bottom=0.5)
             plt.xticks(rotation=80)
@@ -69,3 +80,33 @@ class PlotTransactionSignatures(ReportSection):
         plt.xlabel('Endpoint')
         plt.legend()
         self.add_figure(figure)
+
+    def plot_recall_and_precision(self, signatures):
+        figure = plt.figure()
+        signature1 = signatures[0][1]
+        signature2 = signatures[1][1]
+
+        diffs = []
+        for i, service_time_1 in enumerate(signature1):
+            diff = service_time_1.value - signature2[i].value
+            diffs.append(diff)
+
+        start = min(diffs) - 10
+        end = max(diffs) + 10
+
+        x_values = []
+        false_positive_counts = []
+        while start < end:
+            x_values.append(start)
+            false_positive_count = 0
+            for i, service_time_1 in enumerate(signature1):
+                diff = service_time_1.value - signature2[i].value
+
+                if diff > start and service_time_1.endpoint_name != 'api.add_user':
+                    false_positive_count += 1
+
+            false_positive_counts.append(false_positive_count)
+            start += 1
+
+        plt.plot(x_values, false_positive_counts)
+        self.add_figure(figure)
