@@ -75,12 +75,13 @@ def stop_simulation():
 
     scenario_data = []
 
-    for scenario in simulation.scenarios():
+    for scenario in simulation.running_scenarios():
         scenario_data.append(dict(
             start=scenario.started_at().isoformat(),
             end=scenario.ended_at().isoformat(),
             modifiers=scenario.modifiers(),
-            name=scenario.name()
+            name=scenario.name(),
+            options=scenario.options()
         ))
 
     return jsonify(dict(
