@@ -14,21 +14,16 @@ class Api(object):
             response.status_code)
 
     def stop_simulation(self):
-        response = requests.post(self.host.url('api/simulation/stop'), json=dict(
-            adjust_ms=str(adjust_ms)
-        ))
+        response = requests.post(self.host.url('api/simulation/stop'))
 
         assert response.status_code == 200, 'Request to stop simulation failed due to an unknown error'
 
         return response.json()
 
     def start_scenario(self, name, modifiers, meta, options):
-        response = requests.post(self.host.url('/api/simulation/start-scenario'), json=dict(
-            modifiers=modifiers,
-            meta=meta,
-            name=name,
-            options=options
-        ))
+        payload = dict(modifiers=modifiers, meta=meta, name=name, options=options)
+        print(payload)
+        response = requests.post(self.host.url('/api/simulation/start-scenario'), json=payload)
 
         assert response.status_code == 200
 
